@@ -9,5 +9,9 @@ test.graphTest <- function() {
 	weights <- rbind(c(1, 0, 0, 0, 0), c(0, 1, 0, 0, 0))
 	pvals <- c(0.024, 0.05, 0.01, 0.003, 0.009)
 	out <- graphTest(pvals, weights, alpha=c(0.0125, 0.0125), G=list(G1, G2), verbose = TRUE)
-	
+  graph1 <- matrix2graph(G1, weights[1,])
+  graph2 <- matrix2graph(G2, weights[2,])
+	graph <- new("entangledMCP", subgraphs=list(graph1, graph2), weights=c(0.5,0.5))
+	out_from_objects <- graphTest(pvals, alpha=0.025, graph=graph, verbose = TRUE)
+	all.equal(out, out_from_objects)
 }
\ No newline at end of file
